#
# K2HR3 Utilities - Command Line Interface
#
# Copyright 2021 Yahoo Japan Corporation.
#
# K2HR3 is K2hdkc based Resource and Roles and policy Rules, gathers
# common management information for the cloud.
# K2HR3 can dynamically manage information as "who", "what", "operate".
# These are stored as roles, resources, policies in K2hdkc, and the
# client system can dynamically read and modify these information.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Mon Feb 15 2021
# REVISION:
#

#---------------------------------------------------------------------
# Put Help
#---------------------------------------------------------------------
# [NOTE]
# Adjust the start and end positions of the characters according to the
# scale below, and arrange the lines.
#
#     +-- start position(ex. title)
#     |   +-- indent for description
#     |   |
#     v   v
#     +---+----+----+----+----+----+----+----+----+----+----+----+----|
#
echo ""
echo "K2HR3 Utilities - Command Line Interface"
echo ""
echo "The K2HR3 Command Line Interface (CLI) is a tool for manipulat-"
echo "ing K2HR3 data using the K2HR3 REST API."
echo "All K2HR3 command line interface (CLI) programs are written in"
echo "shell scripts and can be ported to various operating systems."
echo ""
echo "USAGE: ${BINNAME} <command> <option...>"
echo ""
echo "OPTION:"
echo "    ${K2HR3CLI_COMMON_OPT_HELP_LONG}(${K2HR3CLI_COMMON_OPT_HELP_SHORT})"
echo "         Display help."
echo "         If <command> is specified, help for that <command> is"
echo "         displayed."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_VERSION_LONG}(${K2HR3CLI_COMMON_OPT_VERSION_SHORT})"
echo "         Display version information."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_CONFIG_LONG}(${K2HR3CLI_COMMON_OPT_CONFIG_SHORT})"
echo "         Specifies the K2HR3 CLI Configuration file to load at"
echo "         startup. If this option is not specified, the default"
echo "         configuration file will be loaded."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_INTERACTIVE_LONG}(${K2HR3CLI_COMMON_OPT_INTERACTIVE_SHORT})"
echo "         If this option is specified, you will be prompted"
echo "         interactively if there are any unspecified options or"
echo "         parameters. And this option cannot be specified with"
echo "         --nointeractive(-ni)."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_NOINTERACTIVE_LONG}(${K2HR3CLI_COMMON_OPT_NOINTERACTIVE_SHORT})"
echo "         If it finds an unspecified required option, it will"
echo "         make an error. This is the default behavior. And this"
echo "         option cannot be specified with --interactive(-i)."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_NODATE_LONG}(${K2HR3CLI_COMMON_OPT_NODATE_SHORT})"
echo "         The date and time are not displayed in the output"
echo "         message. By default, the date and time are displayed."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_NOCOLOR_LONG}(${K2HR3CLI_COMMON_OPT_NOCOLOR_SHORT})"
echo "         Does not color the output message. By default, it is"
echo "         colored."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_JSON_LONG}(${K2HR3CLI_COMMON_OPT_JSON_SHORT})"
echo "         The json output of the command result is formatted and"
echo "         displayed in an easy-to-understand manner."
echo "         Python json.tool is required to specify this."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_CURLDBG_LONG}(${K2HR3CLI_COMMON_OPT_CURLDBG_SHORT})"
echo "         Specifies the verbose option when executing the curl"
echo "         command."
echo "         If this option is specified, detailed information will"
echo "         be printed to standard error."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_CURLBODY_LONG}(${K2HR3CLI_COMMON_OPT_CURLBODY_SHORT})"
echo "         Shows the response body after executing the curl command."
echo "         If you specify this option, we recommend that you also"
echo "         specify ${K2HR3CLI_COMMON_OPT_CURLDBG_LONG}(${K2HR3CLI_COMMON_OPT_CURLDBG_SHORT})."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_SAVE_LONG}(${K2HR3CLI_COMMON_OPT_SAVE_SHORT})"
echo "        This option can be specified with the TOKEN command."
echo "        If this option is specified, when a (Un)Scoped Token is"
echo "        created, variables such as these tokens and User Name,"
echo "        etc are saved in the configuration file."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_SAVE_PASS_LONG}(${K2HR3CLI_COMMON_OPT_SAVE_PASS_SHORT})"
echo "         This option can be specified with the TOKEN command."
echo "         This option must be specified with the ${K2HR3CLI_COMMON_OPT_SAVE_LONG}(${K2HR3CLI_COMMON_OPT_SAVE_SHORT})"
echo "         option."
echo "         When this option is specified, the user's passphrase is"
echo "         saved in the configuration file if the user credentials"
echo "         are used to create a (Un)Scope Token."
echo "         [NOTE]"
echo "         THIS OPTION IS NOT RECOMMENDED AS IT CAN POSE A"
echo "         SECURITY VULNERABILITY ISSUE."
echo ""
echo "    ${K2HR3CLI_COMMON_OPT_MSGLEVEL_LONG}(${K2HR3CLI_COMMON_OPT_MSGLEVEL_SHORT})"
echo "         This option specifies the output level of the message."
echo "         The following values can be specified for the optional"
echo "         parameters."
echo "             silent, slt, 0            : output nothing"
echo "             error, err, 1             : output only error"
echo "             warning, warn, wan, 2     : more than warning"
echo "             information, info, inf, 3 : more than information"
echo "             debug, dbg, 4             : more than debug"
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_API_URI_LONG}(${K2HR3CLI_COMMAND_OPT_API_URI_SHORT})"
echo "         Specifies the URI to the K2HR3 REST API."
echo "         ex. https://127.0.0.1:3000"
echo "         \"K2HR3CLI_API_URI\" Environment or a variable in"
echo "         configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_USER_LONG}(${K2HR3CLI_COMMAND_OPT_USER_SHORT})"
echo "         Specifies the K2HR3 user name for credential authenti-"
echo "         cation."
echo "         \"K2HR3CLI_USER\" Environment or a variable in"
echo "          configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_PASS_LONG}(${K2HR3CLI_COMMAND_OPT_PASS_SHORT})"
echo "         Specify the K2HR3 passphrase for credential authenti-"
echo "         cation."
echo "         \"K2HR3CLI_PASS\" Environment or a variable in"
echo "         configuration file is instead of this option."
echo "         ${CRED}STRONGLY RECOMMENDED${CDEF} to avoid using this option to"
echo "         prevent leakage from history etc."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_TENANT_LONG}(${K2HR3CLI_COMMAND_OPT_TENANT_SHORT})"
echo "         Specify the tenant(project) to get the Scoped Token."
echo "         \"K2HR3CLI_TENANT\" Environment or a variable in"
echo "         configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_UNSCOPED_TOKEN_LONG}(${K2HR3CLI_COMMAND_OPT_UNSCOPED_TOKEN_SHORT})"
echo "         Specify the Unscoped Token, for example, to get the"
echo "         Scoped Token."
echo "         \"K2HR3CLI_UNSCOPED_TOKEN\" Environment or a variable"
echo "         in configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_SCOPED_TOKEN_LONG}(${K2HR3CLI_COMMAND_OPT_SCOPED_TOKEN_SHORT})"
echo "         Specify the Scoped Token required to call various APIs."
echo "         \"K2HR3CLI_SCOPED_TOKEN\" Environment or a variable in"
echo "         configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_OPENSTACK_TOKEN_LONG}(${K2HR3CLI_COMMAND_OPT_OPENSTACK_TOKEN_SHORT})"
echo "         Specify the Token(Unscoped or Scoped) issued by the"
echo "         OpenStack system to obtain the Unscoped and Scoped"
echo "         Token."
echo "         \"K2HR3CLI_OPENSTACK_TOKEN\" Environment or a variable"
echo "         in configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_OIDC_TOKEN_LONG}(${K2HR3CLI_COMMAND_OPT_OIDC_TOKEN_SHORT})"
echo "         Specify the Access Token issued by the OpenID Connect"
echo "         sequence to obtain the Unscoped and Scoped Token for K2HR3."
echo "         \"K2HR3CLI_OIDC_TOKEN\" Environment or a variable in"
echo "         configuration file is instead of this option."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_EXPAND_LONG}"
echo "         If specified, \"expand=true\" and expands the result."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_POLICIES_LONG}"
echo "         Specifies the policy path."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_ALIAS_LONG}"
echo "         Specifies the alias(to role/resource) path."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_HOST_LONG}"
echo "         Specifies the hostname(or IP address)."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_PORT_LONG}"
echo "         Specifies the port number."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_CUK_LONG}"
echo "         Specifies the CUK url argument for role command."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_EXTRA_LONG}"
echo "         Specifies the EXTRA data url argument for role command."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_TAG_LONG}"
echo "         Specifies the TAG data url argument for role command."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_EXPIRE_LONG}"
echo "         Specifies the expire argument for role command."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_TYPE_LONG}"
echo "         A resource type of the resource. A valid value is"
echo "         \"string\", \"object\", \"null\", or \"undefined\"."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_DATA_LONG}"
echo "         A data of the resource. If the resource type is"
echo "         \"string\", data must be a string literal. If the"
echo "         resource type is \"object\", data must be a JSON object."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_DATAFILE_LONG}"
echo "         A file of the resource which type is \"string\"."
echo "         If the data contains non-escaped characters such as"
echo "         line breaks, you can specify it in the file."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_KEYS_LONG}"
echo "         A pair of a key and a value of the resource."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_SERVICE_LONG}"
echo "         Specifies the service name."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_KEYNAMES_LONG}"
echo "         Specifies the key names in resource."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_ALIASES_LONG}"
echo "         Specifies the alias names."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_EFFECT_LONG}"
echo "         Specifies the effect type for resource."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_ACTION_LONG}"
echo "         Specifies the action type for resource."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_CLEAR_TENANT_LONG}"
echo "         Specify when deleting a tenant from a service member."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_VERIFY_LONG}"
echo "         In the service command, specify the URL to define the"
echo "         dynamic resource or string literal or Boolean literal."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_CIP_LONG}"
echo "         An IP address, which is owned by a service member and"
echo "         the other end IP address of the service owner(a peer IP)."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_CPORT_LONG}"
echo "         An port number, which is used to determine the K2HR3"
echo "         ROLE name of the IP address."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_CROLE_LONG}"
echo "         A K2HR3 ROLE name. If a service member host is a"
echo "         member of multiple K2HR3 ROLE, the service member"
echo "         should pass the K2HR3 ROLE name it want to be"
echo "         authorized."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_CCUK_LONG}"
echo "         This parameter is reserved for future use. Setting this"
echo "         currently has no effect."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_SPORT_LONG}"
echo "         A port number of the service owner host. The IP"
echo "         address of the service owner host is not required."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_SROLE_LONG}"
echo "         A role name assigned to service owner host"
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_SCUK_LONG}"
echo "         This parameter is reserved for future use."
echo ""
echo "    ${K2HR3CLI_COMMAND_OPT_OUTPUT_LONG}"
echo "         Specify the file path to output the command result."
echo "         Specify this option for the K2HR3 REST API, which"
echo "         returns a file."
echo ""
echo "    NOTE:"
echo "         Some options can be replaced by environment variables"
echo "         or variables can be defined in the configuration file."
echo ""
echo "COMMAND:"
echo "    \"${BINNAME} [command] ${K2HR3CLI_COMMON_OPT_HELP_LONG}(${K2HR3CLI_COMMON_OPT_HELP_SHORT})\" to see the usage and formatt"
echo "    -ing details for each \"COMMAND\"."
echo ""

#
# Local variables:
# tab-width: 4
# c-basic-offset: 4
# End:
# vim600: noexpandtab sw=4 ts=4 fdm=marker
# vim<600: noexpandtab sw=4 ts=4
#
